==> zio-aws-dataexchange_2.13-5.17.129.2-sources.jar: zio/aws/dataexchange/model/GetDataSetRequest.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetDataSetRequest(dataSetId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.GetDataSetRequest = {
    import GetDataSetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.GetDataSetRequest
      .builder()
      .dataSetId(__string.unwrap(dataSetId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.GetDataSetRequest.ReadOnly =
    zio.aws.dataexchange.model.GetDataSetRequest.wrap(buildAwsValue())
}
object GetDataSetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.GetDataSetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.GetDataSetRequest =
      zio.aws.dataexchange.model.GetDataSetRequest(dataSetId)
    def dataSetId: __string
    def getDataSetId: ZIO[Any, Nothing, __string] = ZIO.succeed(dataSetId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.GetDataSetRequest
  ) extends zio.aws.dataexchange.model.GetDataSetRequest.ReadOnly {
    override val dataSetId: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.dataSetId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.GetDataSetRequest
  ): zio.aws.dataexchange.model.GetDataSetRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-dataexchange_2.13-5.19.7.1-sources.jar: zio/aws/dataexchange/model/GetDataSetRequest.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetDataSetRequest(dataSetId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.GetDataSetRequest = {
    import GetDataSetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.GetDataSetRequest
      .builder()
      .dataSetId(dataSetId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.GetDataSetRequest.ReadOnly =
    zio.aws.dataexchange.model.GetDataSetRequest.wrap(buildAwsValue())
}
object GetDataSetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.GetDataSetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.GetDataSetRequest =
      zio.aws.dataexchange.model.GetDataSetRequest(dataSetId)
    def dataSetId: __string
    def getDataSetId: ZIO[Any, Nothing, __string] = ZIO.succeed(dataSetId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.GetDataSetRequest
  ) extends zio.aws.dataexchange.model.GetDataSetRequest.ReadOnly {
    override val dataSetId: __string = impl.dataSetId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.GetDataSetRequest
  ): zio.aws.dataexchange.model.GetDataSetRequest.ReadOnly = new Wrapper(impl)
}
